@@ -165,3 +165,21 @@ def test_omex_to_omex(tmp_path: Path) -> None:
 def test_is_omex(omex_path: Path, omex_flag: bool) -> None:
     """Test if path is a COMBINE archive."""
     assert Omex.is_omex(omex_path) == omex_flag
+
+
+def test_entries_by_format() -> None:
+    """Test that entries can be retrieved by format key."""
+    omex = Omex.from_omex(SHOWCASE_OMEX)
+    sbml_entries = omex.entries_by_format("sbml")
+    assert sbml_entries
+    assert len(sbml_entries) == 1
+    assert sbml_entries[0].format.startswith(
+        "http://identifiers.org/combine.specifications/sbml"
+    )
+
+    sedml_entries = omex.entries_by_format("sedml")
+    assert sedml_entries
+    assert len(sedml_entries) == 2
+    assert sedml_entries[0].format.startswith(
+        "http://identifiers.org/combine.specifications/sed-ml"
+    )
